@@ -10,7 +10,6 @@
 #define __E_CONTACT_H__
 
 #include <time.h>
-#include <glib-object.h>
 #include <stdio.h>
 #include <libebook/e-vcard.h>
 
@@ -208,6 +207,14 @@ typedef enum {
 
 	E_CONTACT_SIP,
 
+	E_CONTACT_IM_GOOGLE_TALK_HOME_1,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK_HOME_2,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK_HOME_3,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK_WORK_1,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK_WORK_2,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK_WORK_3,     /* Synthetic string field */
+	E_CONTACT_IM_GOOGLE_TALK,		/* Multi-valued */
+
 	E_CONTACT_FIELD_LAST,
 	E_CONTACT_FIELD_FIRST        = E_CONTACT_UID,
 
@@ -332,8 +339,15 @@ EContactName           *e_contact_name_from_string (const gchar *name_str);
 EContactName           *e_contact_name_copy        (EContactName *n);
 void                    e_contact_name_free        (EContactName *name);
 
-GType                   e_contact_photo_get_type   (void);
-void                    e_contact_photo_free       (EContactPhoto *photo);
+EContactPhoto*          e_contact_photo_new           (void);
+GType                   e_contact_photo_get_type      (void);
+void                    e_contact_photo_free          (EContactPhoto *photo);
+const guchar *          e_contact_photo_get_inlined   (EContactPhoto *photo, gsize *len);
+void                    e_contact_photo_set_inlined   (EContactPhoto *photo, const guchar *data, gsize len);
+const gchar *           e_contact_photo_get_mime_type (EContactPhoto *photo);
+void                    e_contact_photo_set_mime_type (EContactPhoto *photo, const gchar *mime_type);
+const gchar *           e_contact_photo_get_uri       (EContactPhoto *photo);
+void                    e_contact_photo_set_uri       (EContactPhoto *photo, const gchar *uri);
 
 GType			e_contact_geo_get_type	   (void);
 void			e_contact_geo_free	   (EContactGeo *geo);
@@ -341,6 +355,7 @@ void			e_contact_geo_free	   (EContactGeo *geo);
 GType                   e_contact_cert_get_type    (void);
 void                    e_contact_cert_free        (EContactCert *cert);
 
+EContactAddress*        e_contact_address_new      (void);
 GType                   e_contact_address_get_type (void);
 void                    e_contact_address_free     (EContactAddress *address);
 
