@@ -26,6 +26,10 @@
 #include <unistd.h>
 #include <glib/gi18n.h>
 
+#ifdef ENABLE_MAINTAINER_MODE
+#include <gtk/gtk.h>
+#endif
+
 #ifdef G_OS_UNIX
 #if GLIB_CHECK_VERSION(2,29,5)
 #include <glib-unix.h>
@@ -739,6 +743,8 @@ on_name_lost (GDBusConnection *connection,
 	}
 
 	g_mutex_unlock (factory->priv->connections_lock);
+	g_print ("Superseded...\n");
+	g_main_loop_quit (loop);
 }
 
 #ifdef G_OS_UNIX
@@ -799,6 +805,11 @@ main (gint argc, gchar **argv)
 	g_set_prgname (E_PRGNAME);
 	if (!g_thread_supported ()) g_thread_init (NULL);
 
+	#ifdef ENABLE_MAINTAINER_MODE
+	/* only to load gtk-modules, like bug-buddy's gnomesegvhandler, if possible */
+	gtk_init_check (&argc, &argv);
+	#endif
+
 	context = g_option_context_new (NULL);
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_parse (context, &argc, &argv, &error);
@@ -822,7 +833,7 @@ main (gint argc, gchar **argv)
 	owner_id = g_bus_own_name (
 		G_BUS_TYPE_SESSION,
 		ADDRESS_BOOK_DBUS_SERVICE_NAME,
-		G_BUS_NAME_OWNER_FLAGS_NONE,
+		G_BUS_NAME_OWNER_FLAGS_REPLACE | G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT,
 		on_bus_acquired,
 		on_name_acquired,
 		on_name_lost,
