@@ -26,15 +26,15 @@
 
 #include <string.h>
 #include <libebook/e-contact.h>
+#include "libedataserver/e-data-server-util.h"
 #include "e-data-book-view.h"
 
-#include "e-gdbus-egdbusbookview.h"
+#include "e-gdbus-book-view.h"
 
 static void reset_array (GArray *array);
 static void ensure_pending_flush_timeout (EDataBookView *view);
 
 G_DEFINE_TYPE (EDataBookView, e_data_book_view, G_TYPE_OBJECT);
-#define E_DATA_BOOK_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_DATA_BOOK_VIEW, EDataBookViewPrivate))
 
 #define THRESHOLD_ITEMS   32	/* how many items can be hold in a cache, before propagated to UI */
 #define THRESHOLD_SECONDS  2	/* how long to wait until notifications are propagated to UI; in seconds */
@@ -47,7 +47,6 @@ struct _EDataBookViewPrivate {
 
 	gchar * card_query;
 	EBookBackendSExp *card_sexp;
-	gint max_results;
 
 	gboolean running;
 	GMutex *pending_mutex;
@@ -60,6 +59,9 @@ struct _EDataBookViewPrivate {
 	guint idle_id;
 
 	guint flush_id;
+
+	/* which fields is listener interested in */
+	GHashTable *fields_of_interest;
 };
 
 static void e_data_book_view_dispose (GObject *object);
@@ -76,6 +78,43 @@ e_data_book_view_class_init (EDataBookViewClass *klass)
 	object_class->finalize = e_data_book_view_finalize;
 }
 
+static guint
+str_ic_hash (gconstpointer key)
+{
+	guint32 hash = 5381;
+	const gchar *str = key;
+	gint ii;
+
+	if (!str)
+		return hash;
+
+	for (ii = 0; str[ii]; ii++) {
+		hash = hash * 33 + g_ascii_tolower (str[ii]);
+	}
+
+	return hash;
+}
+
+static gboolean
+str_ic_equal (gconstpointer a, gconstpointer b)
+{
+	const gchar *stra = a, *strb = b;
+	gint ii;
+
+	if (!stra && !strb)
+		return TRUE;
+
+	if (!stra || !strb)
+		return FALSE;
+
+	for (ii = 0; stra[ii] && strb[ii]; ii++) {
+		if (g_ascii_tolower (stra[ii]) != g_ascii_tolower (strb[ii]))
+			return FALSE;
+	}
+
+	return stra[ii] == strb[ii];
+}
+
 /**
  * e_data_book_view_register_gdbus_object:
  *
@@ -117,7 +156,7 @@ send_pending_adds (EDataBookView *view)
 	if (priv->adds->len == 0)
 		return;
 
-	e_gdbus_book_view_emit_contacts_added (view->priv->gdbus_object, (const gchar * const *) priv->adds->data);
+	e_gdbus_book_view_emit_objects_added (view->priv->gdbus_object, (const gchar * const *) priv->adds->data);
 	reset_array (priv->adds);
 }
 
@@ -129,7 +168,7 @@ send_pending_changes (EDataBookView *view)
 	if (priv->changes->len == 0)
 		return;
 
-	e_gdbus_book_view_emit_contacts_changed (view->priv->gdbus_object, (const gchar * const *) priv->changes->data);
+	e_gdbus_book_view_emit_objects_modified (view->priv->gdbus_object, (const gchar * const *) priv->changes->data);
 	reset_array (priv->changes);
 }
 
@@ -141,7 +180,7 @@ send_pending_removes (EDataBookView *view)
 	if (priv->removes->len == 0)
 		return;
 
-	e_gdbus_book_view_emit_contacts_removed (view->priv->gdbus_object, (const gchar * const *) priv->removes->data);
+	e_gdbus_book_view_emit_objects_removed (view->priv->gdbus_object, (const gchar * const *) priv->removes->data);
 	reset_array (priv->removes);
 }
 
@@ -176,13 +215,14 @@ ensure_pending_flush_timeout (EDataBookView *view)
 }
 
 /*
- * Queue @vcard to be sent as a change notification. This takes ownership of
- * @vcard.
+ * Queue @vcard to be sent as a change notification.
  */
 static void
-notify_change (EDataBookView *view, gchar *vcard)
+notify_change (EDataBookView *view, const gchar *vcard)
 {
 	EDataBookViewPrivate *priv = view->priv;
+	gchar *utf8_vcard;
+
 	send_pending_adds (view);
 	send_pending_removes (view);
 
@@ -190,18 +230,20 @@ notify_change (EDataBookView *view, gchar *vcard)
 		send_pending_changes (view);
 	}
 
-	g_array_append_val (priv->changes, vcard);
+	utf8_vcard = e_util_utf8_make_valid (vcard);
+	g_array_append_val (priv->changes, utf8_vcard);
 
 	ensure_pending_flush_timeout (view);
 }
 
 /*
- * Queue @id to be sent as a change notification. This takes ownership of @id.
+ * Queue @id to be sent as a change notification.
  */
 static void
-notify_remove (EDataBookView *view, gchar *id)
+notify_remove (EDataBookView *view, const gchar *id)
 {
 	EDataBookViewPrivate *priv = view->priv;
+	gchar *valid_id;
 
 	send_pending_adds (view);
 	send_pending_changes (view);
@@ -210,20 +252,22 @@ notify_remove (EDataBookView *view, gchar *id)
 		send_pending_removes (view);
 	}
 
-	g_array_append_val (priv->removes, id);
-	g_hash_table_remove (priv->ids, id);
+	valid_id = e_util_utf8_make_valid (id);
+	g_array_append_val (priv->removes, valid_id);
+	g_hash_table_remove (priv->ids, valid_id);
 
 	ensure_pending_flush_timeout (view);
 }
 
 /*
- * Queue @id and @vcard to be sent as a change notification. This takes ownership of
- * @vcard but not @id.
+ * Queue @id and @vcard to be sent as a change notification.
  */
 static void
-notify_add (EDataBookView *view, const gchar *id, gchar *vcard)
+notify_add (EDataBookView *view, const gchar *id, const gchar *vcard)
 {
 	EDataBookViewPrivate *priv = view->priv;
+	gchar *utf8_vcard;
+
 	send_pending_changes (view);
 	send_pending_removes (view);
 
@@ -231,13 +275,45 @@ notify_add (EDataBookView *view, const gchar *id, gchar *vcard)
 		send_pending_adds (view);
 	}
 
-	g_array_append_val (priv->adds, vcard);
-	g_hash_table_insert (priv->ids, g_strdup (id),
+	utf8_vcard = e_util_utf8_make_valid (vcard);
+	g_array_append_val (priv->adds, utf8_vcard);
+	g_hash_table_insert (priv->ids, e_util_utf8_make_valid (id),
 			     GUINT_TO_POINTER (1));
 
 	ensure_pending_flush_timeout (view);
 }
 
+static gboolean
+impl_DataBookView_set_fields_of_interest (EGdbusBookView *object, GDBusMethodInvocation *invocation, const gchar * const *in_fields_of_interest, EDataBookView *view)
+{
+	EDataBookViewPrivate *priv;
+	gint ii;
+
+	g_return_val_if_fail (in_fields_of_interest != NULL, TRUE);
+
+	priv = view->priv;
+
+	if (priv->fields_of_interest)
+		g_hash_table_destroy (priv->fields_of_interest);
+	priv->fields_of_interest = NULL;
+
+	for (ii = 0; in_fields_of_interest[ii]; ii++) {
+		const gchar *field = in_fields_of_interest[ii];
+
+		if (!*field)
+			continue;
+
+		if (!priv->fields_of_interest)
+			priv->fields_of_interest = g_hash_table_new_full (str_ic_hash, str_ic_equal, g_free, NULL);
+
+		g_hash_table_insert (priv->fields_of_interest, g_strdup (field), GINT_TO_POINTER (1));
+	}
+
+	e_gdbus_book_view_complete_set_fields_of_interest (object, invocation, NULL);
+
+	return TRUE;
+}
+
 static void
 reset_array (GArray *array)
 {
@@ -254,6 +330,22 @@ reset_array (GArray *array)
 	g_array_set_size (array, 0);
 }
 
+static gboolean
+id_is_in_view (EDataBookView *book_view, const gchar *id)
+{
+	gchar *valid_id;
+	gboolean res;
+
+	g_return_val_if_fail (book_view != NULL, FALSE);
+	g_return_val_if_fail (id != NULL, FALSE);
+
+	valid_id = e_util_utf8_make_valid (id);
+	res = g_hash_table_lookup (book_view->priv->ids, valid_id) != NULL;
+	g_free (valid_id);
+
+	return res;
+}
+
 /**
  * e_data_book_view_notify_update:
  * @book_view: an #EDataBookView
@@ -266,8 +358,7 @@ reset_array (GArray *array)
  * by @book_view.
  **/
 void
-e_data_book_view_notify_update (EDataBookView *book_view,
-                                EContact      *contact)
+e_data_book_view_notify_update (EDataBookView *book_view, const EContact *contact)
 {
 	EDataBookViewPrivate *priv = book_view->priv;
 	gboolean currently_in_view, want_in_view;
@@ -279,12 +370,11 @@ e_data_book_view_notify_update (EDataBookView *book_view,
 
 	g_mutex_lock (priv->pending_mutex);
 
-	id = e_contact_get_const (contact, E_CONTACT_UID);
+	id = e_contact_get_const ((EContact *) contact, E_CONTACT_UID);
 
-	currently_in_view =
-		g_hash_table_lookup (priv->ids, id) != NULL;
+	currently_in_view = id_is_in_view (book_view, id);
 	want_in_view =
-		e_book_backend_sexp_match_contact (priv->card_sexp, contact);
+		e_book_backend_sexp_match_contact (priv->card_sexp, (EContact *) contact);
 
 	if (want_in_view) {
 		vcard = e_vcard_to_string (E_VCARD (contact),
@@ -294,9 +384,11 @@ e_data_book_view_notify_update (EDataBookView *book_view,
 			notify_change (book_view, vcard);
 		else
 			notify_add (book_view, id, vcard);
+
+		g_free (vcard);
 	} else {
 		if (currently_in_view)
-			notify_remove (book_view, g_strdup (id));
+			notify_remove (book_view, id);
 		/* else nothing; we're removing a card that wasn't there */
 	}
 
@@ -324,15 +416,16 @@ e_data_book_view_notify_update_vcard (EDataBookView *book_view, gchar *vcard)
 	const gchar *id;
 	EContact *contact;
 
-	if (!priv->running)
+	if (!priv->running) {
+		g_free (vcard);
 		return;
+	}
 
 	g_mutex_lock (priv->pending_mutex);
 
 	contact = e_contact_new_from_vcard (vcard);
 	id = e_contact_get_const (contact, E_CONTACT_UID);
-	currently_in_view =
-		g_hash_table_lookup (priv->ids, id) != NULL;
+	currently_in_view = id_is_in_view (book_view, id);
 	want_in_view =
 		e_book_backend_sexp_match_contact (priv->card_sexp, contact);
 
@@ -343,13 +436,12 @@ e_data_book_view_notify_update_vcard (EDataBookView *book_view, gchar *vcard)
 			notify_add (book_view, id, vcard);
 	} else {
 		if (currently_in_view)
-			notify_remove (book_view, g_strdup (id));
-		else
-			/* else nothing; we're removing a card that wasn't there */
-			g_free (vcard);
+			notify_remove (book_view, id);
 	}
+
 	/* Do this last so that id is still valid when notify_ is called */
 	g_object_unref (contact);
+	g_free (vcard);
 
 	g_mutex_unlock (priv->pending_mutex);
 }
@@ -380,19 +472,22 @@ e_data_book_view_notify_update_prefiltered_vcard (EDataBookView *book_view, cons
 	EDataBookViewPrivate *priv = book_view->priv;
 	gboolean currently_in_view;
 
-	if (!priv->running)
+	if (!priv->running) {
+		g_free (vcard);
 		return;
+	}
 
 	g_mutex_lock (priv->pending_mutex);
 
-	currently_in_view =
-		g_hash_table_lookup (priv->ids, id) != NULL;
+	currently_in_view = id_is_in_view (book_view, id);
 
 	if (currently_in_view)
 		notify_change (book_view, vcard);
 	else
 		notify_add (book_view, id, vcard);
 
+	g_free (vcard);
+
 	g_mutex_unlock (priv->pending_mutex);
 }
 
@@ -407,15 +502,15 @@ e_data_book_view_notify_update_prefiltered_vcard (EDataBookView *book_view, cons
 void
 e_data_book_view_notify_remove (EDataBookView *book_view, const gchar *id)
 {
-	EDataBookViewPrivate *priv = E_DATA_BOOK_VIEW_GET_PRIVATE (book_view);
+	EDataBookViewPrivate *priv = book_view->priv;
 
 	if (!priv->running)
 		return;
 
 	g_mutex_lock (priv->pending_mutex);
 
-	if (g_hash_table_lookup (priv->ids, id))
-		notify_remove (book_view, g_strdup (id));
+	if (id_is_in_view (book_view, id))
+		notify_remove (book_view, id);
 
 	g_mutex_unlock (priv->pending_mutex);
 }
@@ -433,6 +528,7 @@ void
 e_data_book_view_notify_complete (EDataBookView *book_view, const GError *error)
 {
 	EDataBookViewPrivate *priv = book_view->priv;
+	gchar **strv_error;
 
 	if (!priv->running)
 		return;
@@ -445,15 +541,15 @@ e_data_book_view_notify_complete (EDataBookView *book_view, const GError *error)
 
 	g_mutex_unlock (priv->pending_mutex);
 
-	/* We're done now, so tell the backend to stop?  TODO: this is a bit different to
-	   how the CORBA backend works... */
-
-	e_gdbus_book_view_emit_complete (priv->gdbus_object, error ? error->code : 0, error ? error->message : "");
+	strv_error = e_gdbus_templates_encode_error (error);
+	e_gdbus_book_view_emit_complete (priv->gdbus_object, (const gchar * const *) strv_error);
+	g_strfreev (strv_error);
 }
 
 /**
- * e_data_book_view_notify_status_message:
+ * e_data_book_view_notify_progress:
  * @book_view: an #EDataBookView
+ * @percent: percent done; use -1 when not available
  * @message: a text message
  *
  * Provides listeners with a human-readable text describing the
@@ -461,14 +557,17 @@ e_data_book_view_notify_complete (EDataBookView *book_view, const GError *error)
  * reporting.
  **/
 void
-e_data_book_view_notify_status_message (EDataBookView *book_view, const gchar *message)
+e_data_book_view_notify_progress (EDataBookView *book_view, guint percent, const gchar *message)
 {
-	EDataBookViewPrivate *priv = E_DATA_BOOK_VIEW_GET_PRIVATE (book_view);
+	EDataBookViewPrivate *priv = book_view->priv;
+	gchar *gdbus_message = NULL;
 
 	if (!priv->running)
 		return;
 
-	e_gdbus_book_view_emit_status_message (priv->gdbus_object, message ? message : "");
+	e_gdbus_book_view_emit_progress (priv->gdbus_object, percent, e_util_ensure_gdbus_string (message, &gdbus_message));
+
+	g_free (gdbus_message);
 }
 
 /**
@@ -476,13 +575,12 @@ e_data_book_view_notify_status_message (EDataBookView *book_view, const gchar *m
  * @book: The #EDataBook to search
  * @card_query: The query as a string
  * @card_sexp: The query as an #EBookBackendSExp
- * @max_results: The maximum number of results to return
  *
  * Create a new #EDataBookView for the given #EBook, filtering on #card_sexp,
  * and place it on DBus at the object path #path.
  */
 EDataBookView *
-e_data_book_view_new (EDataBook *book, const gchar *card_query, EBookBackendSExp *card_sexp, gint max_results)
+e_data_book_view_new (EDataBook *book, const gchar *card_query, EBookBackendSExp *card_sexp)
 {
 	EDataBookView *view;
 	EDataBookViewPrivate *priv;
@@ -494,9 +592,8 @@ e_data_book_view_new (EDataBook *book, const gchar *card_query, EBookBackendSExp
 	/* Attach a weak reference to the book, so if it dies the book view is destroyed too */
 	g_object_weak_ref (G_OBJECT (priv->book), book_destroyed_cb, view);
 	priv->backend = g_object_ref (e_data_book_get_backend (book));
-	priv->card_query = g_strdup (card_query);
+	priv->card_query = e_util_utf8_make_valid (card_query);
 	priv->card_sexp = card_sexp;
-	priv->max_results = max_results;
 
 	return view;
 }
@@ -519,7 +616,7 @@ impl_DataBookView_start (EGdbusBookView *object, GDBusMethodInvocation *invocati
 {
 	book_view->priv->idle_id = g_idle_add (bookview_idle_start, book_view);
 
-	e_gdbus_book_view_complete_start (object, invocation);
+	e_gdbus_book_view_complete_start (object, invocation, NULL);
 
 	return TRUE;
 }
@@ -545,7 +642,7 @@ impl_DataBookView_stop (EGdbusBookView *object, GDBusMethodInvocation *invocatio
 
 	book_view->priv->idle_id = g_idle_add (bookview_idle_stop, book_view);
 
-	e_gdbus_book_view_complete_stop (object, invocation);
+	e_gdbus_book_view_complete_stop (object, invocation, NULL);
 
 	return TRUE;
 }
@@ -553,7 +650,10 @@ impl_DataBookView_stop (EGdbusBookView *object, GDBusMethodInvocation *invocatio
 static gboolean
 impl_DataBookView_dispose (EGdbusBookView *object, GDBusMethodInvocation *invocation, EDataBookView *book_view)
 {
-	e_gdbus_book_view_complete_dispose (object, invocation);
+	e_gdbus_book_view_complete_dispose (object, invocation, NULL);
+
+	e_book_backend_stop_book_view (book_view->priv->backend, book_view);
+	book_view->priv->running = FALSE;
 
 	g_object_unref (book_view);
 
@@ -563,14 +663,18 @@ impl_DataBookView_dispose (EGdbusBookView *object, GDBusMethodInvocation *invoca
 static void
 e_data_book_view_init (EDataBookView *book_view)
 {
-	EDataBookViewPrivate *priv = E_DATA_BOOK_VIEW_GET_PRIVATE (book_view);
+	EDataBookViewPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		book_view, E_TYPE_DATA_BOOK_VIEW, EDataBookViewPrivate);
+
 	book_view->priv = priv;
 
 	priv->gdbus_object = e_gdbus_book_view_stub_new ();
 	g_signal_connect (priv->gdbus_object, "handle-start", G_CALLBACK (impl_DataBookView_start), book_view);
 	g_signal_connect (priv->gdbus_object, "handle-stop", G_CALLBACK (impl_DataBookView_stop), book_view);
 	g_signal_connect (priv->gdbus_object, "handle-dispose", G_CALLBACK (impl_DataBookView_dispose), book_view);
+	g_signal_connect (priv->gdbus_object, "handle-set-fields-of-interest", G_CALLBACK (impl_DataBookView_set_fields_of_interest), book_view);
 
+	priv->fields_of_interest = NULL;
 	priv->running = FALSE;
 	priv->pending_mutex = g_mutex_new ();
 
@@ -635,9 +739,11 @@ e_data_book_view_finalize (GObject *object)
 	g_array_free (priv->adds, TRUE);
 	g_array_free (priv->changes, TRUE);
 	g_array_free (priv->removes, TRUE);
-
 	g_free (priv->card_query);
 
+	if (priv->fields_of_interest)
+		g_hash_table_destroy (priv->fields_of_interest);
+
 	g_mutex_free (priv->pending_mutex);
 
 	g_hash_table_destroy (priv->ids);
@@ -645,16 +751,6 @@ e_data_book_view_finalize (GObject *object)
 	G_OBJECT_CLASS (e_data_book_view_parent_class)->finalize (object);
 }
 
-void
-e_data_book_view_set_thresholds (EDataBookView *book_view,
-                                 gint minimum_grouping_threshold,
-                                 gint maximum_grouping_threshold)
-{
-	g_return_if_fail (E_IS_DATA_BOOK_VIEW (book_view));
-
-	g_debug ("e_data_book_view_set_thresholds does nothing in eds-dbus");
-}
-
 /**
  * e_data_book_view_get_card_query:
  * @book_view: an #EDataBookView
@@ -689,23 +785,6 @@ e_data_book_view_get_card_sexp (EDataBookView *book_view)
 	return book_view->priv->card_sexp;
 }
 
-/**
- * e_data_book_view_get_max_results:
- * @book_view: an #EDataBookView
- *
- * Gets the maximum number of results returned by
- * @book_view's query.
- *
- * Returns: The maximum number of results returned.
- **/
-gint
-e_data_book_view_get_max_results (EDataBookView *book_view)
-{
-	g_return_val_if_fail (E_IS_DATA_BOOK_VIEW (book_view), 0);
-
-	return book_view->priv->max_results;
-}
-
 /**
  * e_data_book_view_get_backend:
  * @book_view: an #EDataBookView
@@ -722,6 +801,26 @@ e_data_book_view_get_backend (EDataBookView *book_view)
 	return book_view->priv->backend;
 }
 
+/**
+ * e_data_book_view_get_fields_of_interest:
+ * @view: A view object.
+ *
+ * Returns: Hash table of field names which the listener is interested in.
+ * Backends can return fully populated objects, but the listener advertised
+ * that it will use only these. Returns %NULL for all available fields.
+ *
+ * Note: The data pointer in the hash table has no special meaning, it's
+ * only GINT_TO_POINTER(1) for easier checking. Also, field names are
+ * compared case insensitively.
+ **/
+/* const */ GHashTable *
+e_data_book_view_get_fields_of_interest (EDataBookView *view)
+{
+	g_return_val_if_fail (E_IS_DATA_BOOK_VIEW (view), NULL);
+
+	return view->priv->fields_of_interest;
+}
+
 /**
  * e_data_book_view_ref
  * @book_view: an #EBookView
