@@ -385,7 +385,8 @@ e_data_cal_error_quark (void)
 		{ OtherError,				ERR_PREFIX "OtherError" },
 		{ InvalidServerVersion,			ERR_PREFIX "InvalidServerVersion" },
 		{ InvalidArg,				ERR_PREFIX "InvalidArg" },
-		{ NotSupported,				ERR_PREFIX "NotSupported" }
+		{ NotSupported,				ERR_PREFIX "NotSupported" },
+		{ NotOpened,				ERR_PREFIX "NotOpened" }
 	};
 
 	#undef ERR_PREFIX
@@ -436,7 +437,8 @@ e_data_cal_status_to_string (EDataCalCallStatus status)
 		{ InvalidServerVersion,			N_("Invalid server version") },
 		{ InvalidArg,				N_("Invalid argument") },
 		/* Translators: The string for NOT_SUPPORTED error */
-		{ NotSupported,				N_("Not supported") }
+		{ NotSupported,				N_("Not supported") },
+		{ NotOpened,				N_("Backend is not opened yet") }
 	};
 
 	for (i = 0; i < G_N_ELEMENTS (statuses); i++) {
@@ -1250,7 +1252,7 @@ e_data_cal_respond_discard_alarm (EDataCal *cal, guint32 opid, GError *error)
 	op_complete (cal, opid);
 
 	/* Translators: This is prefix to a detailed error message */
-	g_prefix_error (&error, "%s", _("Could not discard alarm: "));
+	g_prefix_error (&error, "%s", _("Could not discard reminder: "));
 
 	e_gdbus_cal_emit_discard_alarm_done (cal->priv->gdbus_object, opid, error);
 
@@ -1407,6 +1409,25 @@ e_data_cal_report_free_busy_data (EDataCal *cal, const GSList *freebusy)
 	g_strfreev (strv_freebusy);
 }
 
+/* Notifies client about certain property value change */
+void
+e_data_cal_report_backend_property_changed (EDataCal *cal, const gchar *prop_name, const gchar *prop_value)
+{
+	gchar **strv;
+
+	g_return_if_fail (cal != NULL);
+	g_return_if_fail (prop_name != NULL);
+	g_return_if_fail (*prop_name != '\0');
+	g_return_if_fail (prop_value != NULL);
+
+	strv = e_gdbus_templates_encode_two_strings (prop_name, prop_value);
+	g_return_if_fail (strv != NULL);
+
+	e_gdbus_cal_emit_backend_property_changed (cal->priv->gdbus_object, (const gchar * const *) strv);
+
+	g_strfreev (strv);
+}
+
 /* Instance init */
 static void
 e_data_cal_init (EDataCal *ecal)
