@@ -47,7 +47,6 @@
 #define WRITER_LOCK(cdb) g_static_rw_lock_writer_lock (&cdb->priv->rwlock)
 #define WRITER_UNLOCK(cdb) g_static_rw_lock_writer_unlock (&cdb->priv->rwlock)
 
-
 static sqlite3_vfs *old_vfs = NULL;
 static GThreadPool *sync_pool = NULL;
 
@@ -272,7 +271,7 @@ camel_sqlite3_vfs_xOpen (sqlite3_vfs *pVfs, const gchar *zPath, sqlite3_file *pF
 	g_return_val_if_fail (old_vfs != NULL, -1);
 	g_return_val_if_fail (pFile != NULL, -1);
 
-	cFile = (CamelSqlite3File *)pFile;
+	cFile = (CamelSqlite3File *) pFile;
 	cFile->old_vfs_file = g_malloc0 (old_vfs->szOsFile);
 
 	res = old_vfs->xOpen (old_vfs, zPath, cFile->old_vfs_file, flags, pOutFlags);
@@ -366,7 +365,7 @@ struct _CamelDBPrivate {
 static gint
 cdb_sql_exec (sqlite3 *db,
               const gchar *stmt,
-	      gint (*callback)(void*,gint,gchar**,gchar**),
+	      gint (*callback)(gpointer ,gint,gchar **,gchar **),
 	      gpointer data,
               GError **error)
 {
@@ -579,15 +578,14 @@ camel_db_command (CamelDB *cdb,
 
 	if (!cdb)
 		return TRUE;
-	
+
 	WRITER_LOCK (cdb);
 
 	START (stmt);
 	ret = cdb_sql_exec (cdb->db, stmt, NULL, NULL, error);
 	END;
-	
-	WRITER_UNLOCK (cdb);
 
+	WRITER_UNLOCK (cdb);
 
 	return ret;
 }
@@ -627,7 +625,7 @@ camel_db_end_transaction (CamelDB *cdb,
 
 	ret = cdb_sql_exec (cdb->db, "COMMIT", NULL, NULL, error);
 	cdb->priv->transaction_is_on = FALSE;
-	
+
 	ENDTS;
 	WRITER_UNLOCK (cdb);
 	CAMEL_DB_RELEASE_SQLITE_MEMORY;
@@ -738,9 +736,8 @@ camel_db_count_message_info (CamelDB *cdb,
 {
 	gint ret = -1;
 
-
 	READER_LOCK (cdb);
-	
+
 	START (query);
 	ret = cdb_sql_exec (cdb->db, query, count_cb, count, error);
 	END;
@@ -1158,7 +1155,7 @@ camel_db_get_folder_deleted_uids (CamelDB *db,
 static gint
 read_preview_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 {
-	GHashTable *hash = (GHashTable *)ref;
+	GHashTable *hash = (GHashTable *) ref;
 	const gchar *uid=NULL;
 	gchar *msg=NULL;
 	gint i;
@@ -1173,7 +1170,7 @@ read_preview_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 			msg = g_strdup (cols[i]);
 	}
 
-	g_hash_table_insert (hash, (gchar *)uid, msg);
+	g_hash_table_insert (hash, (gchar *) uid, msg);
 
 	return 0;
 }
@@ -1231,7 +1228,7 @@ camel_db_write_preview_record (CamelDB *db,
 static gint
 read_vuids_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 {
-	GPtrArray *array = (GPtrArray *)ref;
+	GPtrArray *array = (GPtrArray *) ref;
 
 	#if 0
 	gint i;
@@ -1435,7 +1432,7 @@ camel_db_migrate_folder_prepare (CamelDB *cdb,
 		ret = camel_db_add_to_transaction (cdb, table_creation_query, error);
 		sqlite3_free (table_creation_query);
 
-		table_creation_query = sqlite3_mprintf ("INSERT INTO 'mem.%q' SELECT uid , flags , msg_type , read , deleted , replied , important , junk , attachment , msg_security , size , dsent , dreceived , subject , mail_from , mail_to , mail_cc , mlist , followup_flag , followup_completed_on , followup_due_by , part , labels , usertags , cinfo , bdata , strftime(\"%%s\", 'now'), strftime(\"%%s\", 'now') FROM %Q", folder_name, folder_name);
+		table_creation_query = sqlite3_mprintf ("INSERT INTO 'mem.%q' SELECT uid , flags , msg_type , read , deleted , replied , important , junk , attachment , dirty , size , dsent , dreceived , subject , mail_from , mail_to , mail_cc , mlist , followup_flag , followup_completed_on , followup_due_by , part , labels , usertags , cinfo , bdata , strftime(\"%%s\", 'now'), strftime(\"%%s\", 'now') FROM %Q", folder_name, folder_name);
 		ret = camel_db_add_to_transaction (cdb, table_creation_query, error);
 		sqlite3_free (table_creation_query);
 
@@ -1541,7 +1538,7 @@ read_version_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 {
 	gint *version = (gint *) ref;
 
-	if (cols [0])
+	if (cols[0])
 		*version = strtoul (cols [0], NULL, 10);
 
 	return 0;
@@ -1552,11 +1549,11 @@ camel_db_get_folder_version (CamelDB *cdb,
                              const gchar *folder_name,
                              GError **error)
 {
-	gint version = -1, ret;
+	gint version = -1;
 	gchar *query;
 
 	query = sqlite3_mprintf ("SELECT version FROM '%q_version'", folder_name);
-	ret = camel_db_select (cdb, query, read_version_callback, &version, error);
+	camel_db_select (cdb, query, read_version_callback, &version, error);
 	sqlite3_free (query);
 
 	return version;
@@ -1587,7 +1584,7 @@ camel_db_prepare_message_info_table (CamelDB *cdb,
 	current_version = camel_db_get_folder_version (cdb, folder_name, &err);
 
 	camel_db_begin_transaction (cdb, &err);
-	
+
 	/* Migration stage one: storing the old data if necessary */
 	ret = camel_db_migrate_folder_prepare (cdb, folder_name, current_version, &err);
 	if (err)
@@ -1602,13 +1599,13 @@ camel_db_prepare_message_info_table (CamelDB *cdb,
 	ret = camel_db_write_folder_version (cdb, folder_name, current_version, &err);
 	if (err)
 		goto exit;
-	
+
 	camel_db_end_transaction (cdb, &err);
 
 exit:
 	if (err && cdb->priv->transaction_is_on)
 		camel_db_abort_transaction (cdb, NULL);
-	
+
 	if (err)
 		g_propagate_error (error, err);
 
