@@ -77,6 +77,8 @@ typedef enum { /*< flags >*/
  * them suitable interpretations.  Use #CAMEL_FOLDER_TYPE_MASK to isolate
  * the folder's type.
  **/
+/* WARNING: This enum and CamelStoreInfoFlags must stay in sync.
+ * FIXME: Eliminate the need for two separate types. */
 typedef enum { /*< flags >*/
 	CAMEL_FOLDER_NOSELECT      = 1 << 0,
 	CAMEL_FOLDER_NOINFERIORS   = 1 << 1,
@@ -98,11 +100,50 @@ typedef enum { /*< flags >*/
 	CAMEL_FOLDER_CHECK_FOR_NEW = 1 << 17,
 	CAMEL_FOLDER_FLAGGED       = 1 << 18,
 
-	CAMEL_FOLDER_FLAGS_LAST    = 1 << 24
+	CAMEL_FOLDER_FLAGS_LAST    = 1 << 24  /*< skip >*/
 } CamelFolderInfoFlags;
 
 #define CAMEL_FOLDER_TYPE_MASK (63 << CAMEL_FOLDER_TYPE_BIT)
 
+/* WARNING: This enum and CamelFolderInfoFlags must stay in sync.
+ * FIXME: Eliminate the need for two separate types. */
+typedef enum { /*< flags >*/
+	CAMEL_STORE_INFO_FOLDER_NOSELECT      = 1 << 0,
+	CAMEL_STORE_INFO_FOLDER_NOINFERIORS   = 1 << 1,
+	CAMEL_STORE_INFO_FOLDER_CHILDREN      = 1 << 2,
+	CAMEL_STORE_INFO_FOLDER_NOCHILDREN    = 1 << 3,
+	CAMEL_STORE_INFO_FOLDER_SUBSCRIBED    = 1 << 4,
+	CAMEL_STORE_INFO_FOLDER_VIRTUAL       = 1 << 5,
+	CAMEL_STORE_INFO_FOLDER_SYSTEM        = 1 << 6,
+	CAMEL_STORE_INFO_FOLDER_VTRASH        = 1 << 7,
+	CAMEL_STORE_INFO_FOLDER_SHARED_TO_ME  = 1 << 8,
+	CAMEL_STORE_INFO_FOLDER_SHARED_BY_ME  = 1 << 9,
+	CAMEL_STORE_INFO_FOLDER_READONLY      = 1 << 16,
+	CAMEL_STORE_INFO_FOLDER_CHECK_FOR_NEW = 1 << 17,
+	CAMEL_STORE_INFO_FOLDER_FLAGGED       = 1 << 18,
+
+	CAMEL_STORE_INFO_FOLDER_LAST          = 1 << 24  /*< skip >*/
+} CamelStoreInfoFlags;
+
+/**
+ * CamelFetchHeadersType:
+ * @CAMEL_FETCH_HEADERS_BASIC:
+ *     Fetch only basic headers (Date, From, To, Subject, etc.).
+ * @CAMEL_FETCH_HEADERS_BASIC_AND_MAILING_LIST:
+ *     Fetch all basic headers and mailing list headers.
+ * @CAMEL_FETCH_HEADERS_ALL:
+ *     Fetch all available message headers.
+ *
+ * Describes what headers to fetch when downloading message summaries.
+ *
+ * Since: 3.2
+ **/
+typedef enum {
+	CAMEL_FETCH_HEADERS_BASIC,
+	CAMEL_FETCH_HEADERS_BASIC_AND_MAILING_LIST,
+	CAMEL_FETCH_HEADERS_ALL
+} CamelFetchHeadersType;
+
 typedef enum {
 	CAMEL_JUNK_STATUS_INCONCLUSIVE,
 	CAMEL_JUNK_STATUS_MESSAGE_IS_JUNK,
@@ -232,15 +273,29 @@ typedef enum {
 	CAMEL_SESSION_ALERT_ERROR
 } CamelSessionAlertType;
 
+/**
+ * CamelSortType:
+ * @CAMEL_SORT_ASCENDING:
+ *   Sorting is in ascending order.
+ * @CAMEL_SORT_DESCENDING:
+ *   Sorting is in descending order.
+ *
+ * Determines the direction of a sort.
+ *
+ * Since: 3.2
+ **/
+typedef enum {
+	CAMEL_SORT_ASCENDING,
+	CAMEL_SORT_DESCENDING
+} CamelSortType;
+
 typedef enum { /*< flags >*/
-	CAMEL_STORE_SUBSCRIPTIONS    = 1 << 0,
-	CAMEL_STORE_VTRASH           = 1 << 1,
-	CAMEL_STORE_FILTER_INBOX     = 1 << 2,
-	CAMEL_STORE_VJUNK            = 1 << 3,
-	CAMEL_STORE_PROXY            = 1 << 4,
-	CAMEL_STORE_IS_MIGRATING     = 1 << 5,
-	CAMEL_STORE_ASYNC            = 1 << 6,
-	CAMEL_STORE_REAL_JUNK_FOLDER = 1 << 7
+	CAMEL_STORE_VTRASH           = 1 << 0,
+	CAMEL_STORE_VJUNK            = 1 << 1,
+	CAMEL_STORE_PROXY            = 1 << 2,
+	CAMEL_STORE_IS_MIGRATING     = 1 << 3,
+	CAMEL_STORE_REAL_JUNK_FOLDER = 1 << 4,
+	CAMEL_STORE_CAN_EDIT_FOLDERS = 1 << 5
 } CamelStoreFlags;
 
 /**
@@ -264,25 +319,6 @@ typedef enum { /*< flags >*/
 	CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST = 1 << 4
 } CamelStoreGetFolderInfoFlags;
 
-/* FIXME: this needs to track the CAMEL_FOLDER_* flags in camel-store.h */
-typedef enum { /*< flags >*/
-	CAMEL_STORE_INFO_FOLDER_NOSELECT      = CAMEL_FOLDER_NOSELECT,
-	CAMEL_STORE_INFO_FOLDER_NOINFERIORS   = CAMEL_FOLDER_NOINFERIORS,
-	CAMEL_STORE_INFO_FOLDER_CHILDREN      = CAMEL_FOLDER_CHILDREN,
-	CAMEL_STORE_INFO_FOLDER_NOCHILDREN    = CAMEL_FOLDER_NOCHILDREN,
-	CAMEL_STORE_INFO_FOLDER_SUBSCRIBED    = CAMEL_FOLDER_SUBSCRIBED,
-	CAMEL_STORE_INFO_FOLDER_VIRTUAL       = CAMEL_FOLDER_VIRTUAL,
-	CAMEL_STORE_INFO_FOLDER_SYSTEM        = CAMEL_FOLDER_SYSTEM,
-	CAMEL_STORE_INFO_FOLDER_VTRASH        = CAMEL_FOLDER_VTRASH,
-	CAMEL_STORE_INFO_FOLDER_SHARED_BY_ME  = CAMEL_FOLDER_SHARED_BY_ME,
-	CAMEL_STORE_INFO_FOLDER_SHARED_TO_ME  = CAMEL_FOLDER_SHARED_TO_ME,
-	CAMEL_STORE_INFO_FOLDER_READONLY      = CAMEL_FOLDER_READONLY,
-	CAMEL_STORE_INFO_FOLDER_CHECK_FOR_NEW = CAMEL_FOLDER_CHECK_FOR_NEW,
-	CAMEL_STORE_INFO_FOLDER_FLAGGED       = CAMEL_FOLDER_FLAGGED,
-
-	CAMEL_STORE_INFO_FOLDER_LAST          = CAMEL_FOLDER_FLAGS_LAST
-} CamelStoreInfoFlags;
-
 typedef enum { /*< flags >*/
 	CAMEL_STORE_READ  = 1 << 0,
 	CAMEL_STORE_WRITE = 1 << 1
