@@ -166,6 +166,7 @@ multipart_signed_parse_content (CamelMultipartSigned *mps)
 				mps->end1--;
 		} else {
 			g_warning("multipart/signed has more than 2 parts, remaining parts ignored");
+			state = CAMEL_MIME_PARSER_STATE_MULTIPART_END;
 			break;
 		}
 
@@ -711,6 +712,9 @@ camel_multipart_signed_get_content_stream (CamelMultipartSigned *mps,
 
 		g_object_unref (filter_stream);
 		g_object_unref (base_stream);
+
+		/* rewind to the beginning of a stream */
+		g_seekable_seek (G_SEEKABLE (constream), 0, G_SEEK_SET, NULL, NULL);
 	}
 
 	return constream;
