@@ -54,9 +54,11 @@ typedef struct _AsyncContext AsyncContext;
 struct _CamelServicePrivate {
 	gpointer session;  /* weak pointer */
 
+	CamelSettings *settings;
 	CamelProvider *provider;
 	CamelURL *url;
 
+	gchar *display_name;
 	gchar *user_data_dir;
 	gchar *uid;
 
@@ -73,8 +75,10 @@ struct _AsyncContext {
 
 enum {
 	PROP_0,
+	PROP_DISPLAY_NAME,
 	PROP_PROVIDER,
 	PROP_SESSION,
+	PROP_SETTINGS,
 	PROP_UID,
 	PROP_URL
 };
@@ -227,6 +231,12 @@ service_set_property (GObject *object,
                       GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_DISPLAY_NAME:
+			camel_service_set_display_name (
+				CAMEL_SERVICE (object),
+				g_value_get_string (value));
+			return;
+
 		case PROP_PROVIDER:
 			service_set_provider (
 				CAMEL_SERVICE (object),
@@ -239,6 +249,12 @@ service_set_property (GObject *object,
 				g_value_get_object (value));
 			return;
 
+		case PROP_SETTINGS:
+			camel_service_set_settings (
+				CAMEL_SERVICE (object),
+				g_value_get_object (value));
+			return;
+
 		case PROP_UID:
 			service_set_uid (
 				CAMEL_SERVICE (object),
@@ -262,6 +278,12 @@ service_get_property (GObject *object,
                       GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_DISPLAY_NAME:
+			g_value_set_string (
+				value, camel_service_get_display_name (
+				CAMEL_SERVICE (object)));
+			return;
+
 		case PROP_PROVIDER:
 			g_value_set_pointer (
 				value, camel_service_get_provider (
@@ -274,6 +296,12 @@ service_get_property (GObject *object,
 				CAMEL_SERVICE (object)));
 			return;
 
+		case PROP_SETTINGS:
+			g_value_set_object (
+				value, camel_service_get_settings (
+				CAMEL_SERVICE (object)));
+			return;
+
 		case PROP_UID:
 			g_value_set_string (
 				value, camel_service_get_uid (
@@ -303,6 +331,11 @@ service_dispose (GObject *object)
 		priv->session = NULL;
 	}
 
+	if (priv->settings != NULL) {
+		g_object_unref (priv->settings);
+		priv->settings = NULL;
+	}
+
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (camel_service_parent_class)->dispose (object);
 }
@@ -321,6 +354,7 @@ service_finalize (GObject *object)
 	if (priv->url != NULL)
 		camel_url_free (priv->url);
 
+	g_free (priv->display_name);
 	g_free (priv->user_data_dir);
 	g_free (priv->uid);
 
@@ -549,6 +583,7 @@ camel_service_class_init (CamelServiceClass *class)
 	object_class->finalize = service_finalize;
 	object_class->constructed = service_constructed;
 
+	class->settings_type = CAMEL_TYPE_SETTINGS;
 	class->get_name = service_get_name;
 	class->cancel_connect = service_cancel_connect;
 	class->connect_sync = service_connect_sync;
@@ -558,6 +593,18 @@ camel_service_class_init (CamelServiceClass *class)
 	class->query_auth_types = service_query_auth_types;
 	class->query_auth_types_finish = service_query_auth_types_finish;
 
+	g_object_class_install_property (
+		object_class,
+		PROP_DISPLAY_NAME,
+		g_param_spec_string (
+			"display-name",
+			"Display Name",
+			"The display name for the service",
+			NULL,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_PROVIDER,
@@ -581,6 +628,18 @@ camel_service_class_init (CamelServiceClass *class)
 			G_PARAM_CONSTRUCT_ONLY |
 			G_PARAM_STATIC_STRINGS));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_SETTINGS,
+		g_param_spec_object (
+			"settings",
+			"Settings",
+			"A CamelSettings instance",
+			CAMEL_TYPE_SETTINGS,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_UID,
@@ -660,6 +719,58 @@ camel_service_cancel_connect (CamelService *service)
 	camel_service_unlock (service, CAMEL_SERVICE_CONNECT_OP_LOCK);
 }
 
+/**
+ * camel_service_get_display_name:
+ * @service: a #CamelService
+ *
+ * Returns the display name for @service, or %NULL if @service has not
+ * been given a display name.  The display name is intended for use in
+ * a user interface and should generally be given a user-defined name.
+ *
+ * Compare this with camel_service_get_name(), which returns a built-in
+ * description of the type of service (IMAP, SMTP, etc.).
+ *
+ * Returns: the display name for @service, or %NULL
+ *
+ * Since: 3.2
+ **/
+const gchar *
+camel_service_get_display_name (CamelService *service)
+{
+	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
+
+	return service->priv->display_name;
+}
+
+/**
+ * camel_service_set_display_name:
+ * @service: a #CamelService
+ * @display_name: a valid UTF-8 string, or %NULL
+ *
+ * Assigns a UTF-8 display name to @service.  The display name is intended
+ * for use in a user interface and should generally be given a user-defined
+ * name.
+ *
+ * Compare this with camel_service_get_name(), which returns a built-in
+ * description of the type of service (IMAP, SMTP, etc.).
+ *
+ * Since: 3.2
+ **/
+void
+camel_service_set_display_name (CamelService *service,
+                                const gchar *display_name)
+{
+	g_return_if_fail (CAMEL_IS_SERVICE (service));
+
+	if (display_name != NULL)
+		g_return_if_fail (g_utf8_validate (display_name, -1, NULL));
+
+	g_free (service->priv->display_name);
+	service->priv->display_name = g_strdup (display_name);
+
+	g_object_notify (G_OBJECT (service), "display-name");
+}
+
 /**
  * camel_service_get_user_data_dir:
  * @service: a #CamelService
@@ -740,6 +851,74 @@ camel_service_get_session (CamelService *service)
 	return CAMEL_SESSION (service->priv->session);
 }
 
+/**
+ * camel_service_get_settings:
+ * @service: a #CamelService
+ *
+ * Returns the #CamelSettings instance associated with the service.
+ *
+ * Returns: the #CamelSettings
+ *
+ * Since: 3.2
+ **/
+CamelSettings *
+camel_service_get_settings (CamelService *service)
+{
+	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
+
+	/* Every service should have a settings object. */
+	g_warn_if_fail (service->priv->settings != NULL);
+
+	return service->priv->settings;
+}
+
+/**
+ * camel_service_set_settings:
+ * @service: a #CamelService
+ * @settings: an instance derviced from #CamelSettings, or %NULL
+ *
+ * Associates a new #CamelSettings instance with the service.
+ * The @settings instance must match the settings type defined in
+ * #CamelServiceClass.  If @settings is %NULL, a new #CamelSettings
+ * instance of the appropriate type is created with all properties
+ * set to defaults.
+ *
+ * Since: 3.2
+ **/
+void
+camel_service_set_settings (CamelService *service,
+                            CamelSettings *settings)
+{
+	CamelServiceClass *class;
+
+	g_return_if_fail (CAMEL_IS_SERVICE (service));
+
+	class = CAMEL_SERVICE_GET_CLASS (service);
+
+	if (settings != NULL) {
+		g_return_if_fail (
+			g_type_is_a (
+				G_OBJECT_TYPE (settings),
+				class->settings_type));
+		g_object_ref (settings);
+
+	} else {
+		g_return_if_fail (
+			g_type_is_a (
+				class->settings_type,
+				CAMEL_TYPE_SETTINGS));
+		settings = g_object_new (class->settings_type, NULL);
+		camel_settings_load_from_url (settings, camel_service_get_camel_url (service));
+	}
+
+	if (service->priv->settings != NULL)
+		g_object_unref (service->priv->settings);
+
+	service->priv->settings = settings;
+
+	g_object_notify (G_OBJECT (service), "settings");
+}
+
 /**
  * camel_service_get_uid:
  * @service: a #CamelService
