@@ -369,9 +369,16 @@ local_folder_refresh_info_sync (CamelFolder *folder,
                                 GCancellable *cancellable,
                                 GError **error)
 {
+	CamelStore *parent_store;
 	CamelLocalFolder *lf = (CamelLocalFolder *) folder;
+	gboolean need_summary_check;
 
-	if (lf->need_summary_check &&
+	parent_store = camel_folder_get_parent_store (folder);
+
+	need_summary_check = camel_local_store_get_need_summary_check (
+		CAMEL_LOCAL_STORE (parent_store));
+
+	if (need_summary_check &&
 	    camel_local_summary_check ((CamelLocalSummary *) folder->summary, lf->changes, cancellable, error) == -1)
 		return FALSE;
 
@@ -512,15 +519,14 @@ camel_local_folder_construct (CamelLocalFolder *lf,
 	CamelLocalStore *ls;
 	CamelStore *parent_store;
 	const gchar *full_name;
-	const gchar *summary_check;
-	CamelURL *url;
+	gboolean need_summary_check;
 
 	folder = CAMEL_FOLDER (lf);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
 	ls = CAMEL_LOCAL_STORE (parent_store);
-	url = camel_service_get_camel_url (CAMEL_SERVICE (parent_store));
+	need_summary_check = camel_local_store_get_need_summary_check (ls);
 
 	root_dir_path = camel_local_store_get_toplevel_dir (ls);
 	/* strip the trailing '/' which is always present */
@@ -540,12 +546,6 @@ camel_local_folder_construct (CamelLocalFolder *lf,
 	camel_object_set_state_filename (CAMEL_OBJECT (lf), statepath);
 	g_free (statepath);
 
-	summary_check = camel_url_get_param (url, "need-summary-check");
-	if (summary_check && !strcmp (summary_check, "no"))
-		lf->need_summary_check = FALSE;
-	else
-		lf->need_summary_check = TRUE;
-
 	lf->flags = flags;
 
 	if (camel_object_state_read (CAMEL_OBJECT (lf)) == -1) {
@@ -610,7 +610,7 @@ camel_local_folder_construct (CamelLocalFolder *lf,
 	folder->summary = (CamelFolderSummary *) CAMEL_LOCAL_FOLDER_GET_CLASS (lf)->create_summary (lf, lf->summary_path, lf->folder_path, lf->index);
 	if (!(flags & CAMEL_STORE_IS_MIGRATING) && camel_local_summary_load ((CamelLocalSummary *) folder->summary, forceindex, NULL) == -1) {
 		/* ? */
-		if (lf->need_summary_check &&
+		if (need_summary_check &&
 		    camel_local_summary_check ((CamelLocalSummary *) folder->summary, lf->changes, cancellable, error) == 0) {
 			/* we sync here so that any hard work setting up the folder isn't lost */
 			if (camel_local_summary_sync ((CamelLocalSummary *) folder->summary, FALSE, lf->changes, cancellable, error) == -1) {
