@@ -77,7 +77,7 @@ maildir_store_create_folder_sync (CamelStore *store,
 	       GCancellable *cancellable,
                GError **error)
 {
-	gchar *path = ((CamelLocalStore *)store)->toplevel_dir;
+	gchar *path = ((CamelLocalStore *) store)->toplevel_dir;
 	gchar *name;
 	CamelFolder *folder;
 	CamelFolderInfo *info = NULL;
@@ -371,7 +371,7 @@ fill_fi (CamelStore *store,
 		const gchar *root;
 
 		/* This should be fast enough not to have to test for INFO_FAST */
-		root = camel_local_store_get_toplevel_dir ((CamelLocalStore *)store);
+		root = camel_local_store_get_toplevel_dir ((CamelLocalStore *) store);
 
 		dir_name = maildir_full_name_to_dir_name (fi->full_name);
 
@@ -383,7 +383,7 @@ fill_fi (CamelStore *store,
 			folderpath = g_strdup_printf("%s%s", root, dir_name);
 		}
 
-		s = (CamelFolderSummary *)camel_maildir_summary_new (NULL, path, folderpath, NULL);
+		s = (CamelFolderSummary *) camel_maildir_summary_new (NULL, path, folderpath, NULL);
 		if (camel_folder_summary_header_load_from_db (s, store, fi->full_name, NULL) != -1) {
 			fi->unread = s->unread_count;
 			fi->total = s->saved_count;
@@ -654,6 +654,37 @@ maildir_store_get_inbox_sync (CamelStore *store,
 		store, "Inbox", CAMEL_STORE_FOLDER_CREATE, cancellable, error);
 }
 
+static gboolean
+rename_traverse_fi (CamelStore *store, CamelStoreClass *store_class, CamelFolderInfo *fi, const gchar *old_full_name_prefix, const gchar *new_full_name_prefix, GCancellable *cancellable, GError **error)
+{
+	gint old_prefix_len = strlen (old_full_name_prefix);
+	gboolean ret = TRUE;
+
+	while (fi && ret) {
+		if (fi->full_name && g_str_has_prefix (fi->full_name, old_full_name_prefix)) {
+			gchar *new_full_name, *old_dir, *new_dir;
+
+			new_full_name = g_strconcat (new_full_name_prefix, fi->full_name + old_prefix_len, NULL);
+			old_dir = maildir_full_name_to_dir_name (fi->full_name);
+			new_dir = maildir_full_name_to_dir_name (new_full_name);
+
+			/* Chain up to parent's rename_folder_sync() method. */
+			ret = store_class->rename_folder_sync (store, old_dir, new_dir, cancellable, error);
+
+			g_free (old_dir);
+			g_free (new_dir);
+			g_free (new_full_name);
+		}
+
+		if (fi->child && !rename_traverse_fi (store, store_class, fi->child, old_full_name_prefix, new_full_name_prefix, cancellable, error))
+			return FALSE;
+
+		fi = fi->next;
+	}
+
+	return ret;
+}
+
 static gboolean
 maildir_store_rename_folder_sync (CamelStore *store,
                                   const gchar *old,
@@ -664,6 +695,7 @@ maildir_store_rename_folder_sync (CamelStore *store,
 	CamelStoreClass *store_class;
 	gboolean ret;
 	gchar *old_dir, *new_dir;
+	CamelFolderInfo *subfolders;
 
 	if (strcmp(old, ".") == 0) {
 		g_set_error (
@@ -691,6 +723,8 @@ maildir_store_rename_folder_sync (CamelStore *store,
 		return FALSE;
 	}
 
+	subfolders = maildir_store_get_folder_info_sync (store, old, CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL, cancellable, NULL);
+
 	old_dir = maildir_full_name_to_dir_name (old);
 	new_dir = maildir_full_name_to_dir_name (new);
 
@@ -699,6 +733,13 @@ maildir_store_rename_folder_sync (CamelStore *store,
 	ret = store_class->rename_folder_sync (
 		store, old_dir, new_dir, cancellable, error);
 
+	if (subfolders) {
+		if (ret)
+			ret = rename_traverse_fi (store, store_class, subfolders->child, old, new, cancellable, error);
+
+		camel_store_free_folder_info (store, subfolders);
+	}
+
 	g_free (old_dir);
 	g_free (new_dir);
 
@@ -806,7 +847,7 @@ scan_old_dir_info (CamelStore *store, CamelFolderInfo *topfi, GError **error)
 
 	sn = g_malloc0 (sizeof (*sn));
 	sn->fi = topfi;
-	camel_dlist_addtail (&queue, (CamelDListNode *)sn);
+	camel_dlist_addtail (&queue, (CamelDListNode *) sn);
 	g_hash_table_insert (visited, sn, sn);
 
 	while (!camel_dlist_empty (&queue)) {
@@ -815,7 +856,7 @@ scan_old_dir_info (CamelStore *store, CamelFolderInfo *topfi, GError **error)
 		struct dirent *d;
 		CamelFolderInfo *last;
 
-		sn = (struct _scan_node *)camel_dlist_remhead (&queue);
+		sn = (struct _scan_node *) camel_dlist_remhead (&queue);
 
 		last = (CamelFolderInfo *)&sn->fi->child;
 
@@ -876,7 +917,7 @@ scan_old_dir_info (CamelStore *store, CamelFolderInfo *topfi, GError **error)
 					snew->fi->parent = sn->fi;
 
 					g_hash_table_insert (visited, snew, snew);
-					camel_dlist_addtail (&queue, (CamelDListNode *)snew);
+					camel_dlist_addtail (&queue, (CamelDListNode *) snew);
 				}
 			}
 			g_free (tmp);
@@ -905,7 +946,7 @@ maildir_rename_old_folder (CamelMaildirStore *mstore, CamelFolderInfo *fi, GCanc
 
 	store_class = CAMEL_STORE_CLASS (camel_maildir_store_parent_class);
 	store_class->rename_folder_sync (
-		(CamelStore *)mstore, fi->full_name, new_name, cancellable, error);
+		(CamelStore *) mstore, fi->full_name, new_name, cancellable, error);
 
 	g_free (old_name);
 	g_free (new_name);
