@@ -71,15 +71,28 @@ camel_nntp_folder_selected (CamelNNTPFolder *nntp_folder,
 {
 	CamelFolder *folder;
 	CamelStore *parent_store;
+	gboolean res;
 
 	folder = CAMEL_FOLDER (nntp_folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
-	return camel_nntp_summary_check (
+	res = camel_nntp_summary_check (
 		CAMEL_NNTP_SUMMARY (folder->summary),
 		CAMEL_NNTP_STORE (parent_store),
 		line, nntp_folder->changes,
 		cancellable, error);
+
+	if (camel_folder_change_info_changed (nntp_folder->changes)) {
+		CamelFolderChangeInfo *changes;
+
+		changes = nntp_folder->changes;
+		nntp_folder->changes = camel_folder_change_info_new ();
+
+		camel_folder_changed (CAMEL_FOLDER (nntp_folder), changes);
+		camel_folder_change_info_free (changes);
+	}
+
+	return res;
 }
 
 static gboolean
@@ -226,6 +239,9 @@ nntp_folder_download_message (CamelNNTPFolder *nntp_folder,
 			if (camel_stream_write_to_stream ((CamelStream *) nntp_store->stream, stream, cancellable, error) == -1)
 				goto fail;
 
+			if ((error && *error) || g_cancellable_set_error_if_cancelled (cancellable, error))
+				goto fail;
+
 			success = g_seekable_seek (
 				G_SEEKABLE (stream), 0,
 				G_SEEK_SET, cancellable, error);
@@ -248,6 +264,7 @@ nntp_folder_download_message (CamelNNTPFolder *nntp_folder,
 	return stream;
 
 fail:
+	camel_data_cache_remove (nntp_store->cache, "cache", msgid, NULL);
 	g_prefix_error (error, _("Cannot get message %s: "), msgid);
 
 	return NULL;
