@@ -33,22 +33,19 @@
 
 #include <glib/gi18n-lib.h>
 
-#include "camel-nntp-summary.h"
-#include "camel-nntp-store.h"
-#include "camel-nntp-store-summary.h"
 #include "camel-nntp-folder.h"
 #include "camel-nntp-private.h"
 #include "camel-nntp-resp-codes.h"
+#include "camel-nntp-settings.h"
+#include "camel-nntp-store-summary.h"
+#include "camel-nntp-store.h"
+#include "camel-nntp-summary.h"
 
 #ifdef G_OS_WIN32
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #endif
 
-#define CAMEL_NNTP_STORE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_NNTP_STORE, CamelNNTPStorePrivate))
-
 #define w(x)
 #define dd(x) (camel_debug("nntp")?(x):0)
 
@@ -57,22 +54,12 @@
 
 #define DUMP_EXTENSIONS
 
-struct _CamelNNTPStorePrivate {
-	gint placeholder;
-};
-
-enum {
-	PROP_0,
-	PROP_DEFAULT_PORT,
-	PROP_SECURITY_METHOD,
-	PROP_SERVICE_NAME
-};
-
 static GInitableIface *parent_initable_interface;
 
 /* Forward Declarations */
 static void camel_nntp_store_initable_init (GInitableIface *interface);
 static void camel_network_service_init (CamelNetworkServiceInterface *interface);
+static void camel_subscribable_init (CamelSubscribableInterface *interface);
 
 G_DEFINE_TYPE_WITH_CODE (
 	CamelNNTPStore,
@@ -83,7 +70,10 @@ G_DEFINE_TYPE_WITH_CODE (
 		camel_nntp_store_initable_init)
 	G_IMPLEMENT_INTERFACE (
 		CAMEL_TYPE_NETWORK_SERVICE,
-		camel_network_service_init))
+		camel_network_service_init)
+	G_IMPLEMENT_INTERFACE (
+		CAMEL_TYPE_SUBSCRIBABLE,
+		camel_subscribable_init))
 
 static gint
 camel_nntp_try_authenticate (CamelNNTPStore *store,
@@ -166,55 +156,6 @@ camel_nntp_try_authenticate (CamelNNTPStore *store,
 	return ret;
 }
 
-static void
-nntp_store_set_property (GObject *object,
-                         guint property_id,
-                         const GValue *value,
-                         GParamSpec *pspec)
-{
-	switch (property_id) {
-		case PROP_SECURITY_METHOD:
-			camel_network_service_set_security_method (
-				CAMEL_NETWORK_SERVICE (object),
-				g_value_get_uint (value));
-			return;
-	}
-
-	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-}
-
-static void
-nntp_store_get_property (GObject *object,
-                         guint property_id,
-                         GValue *value,
-                         GParamSpec *pspec)
-{
-	switch (property_id) {
-		case PROP_DEFAULT_PORT:
-			g_value_set_uint (
-				value,
-				camel_network_service_get_default_port (
-				CAMEL_NETWORK_SERVICE (object)));
-			return;
-
-		case PROP_SECURITY_METHOD:
-			g_value_set_uint (
-				value,
-				camel_network_service_get_security_method (
-				CAMEL_NETWORK_SERVICE (object)));
-			return;
-
-		case PROP_SERVICE_NAME:
-			g_value_set_string (
-				value,
-				camel_network_service_get_service_name (
-				CAMEL_NETWORK_SERVICE (object)));
-			return;
-	}
-
-	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-}
-
 static void
 nntp_store_dispose (GObject *object)
 {
@@ -276,32 +217,6 @@ nntp_store_finalize (GObject *object)
 	G_OBJECT_CLASS (camel_nntp_store_parent_class)->finalize (object);
 }
 
-static void
-nntp_store_constructed (GObject *object)
-{
-	CamelURL *url;
-	const gchar *use_ssl;
-
-	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (camel_nntp_store_parent_class)->constructed (object);
-
-	url = camel_service_get_camel_url (CAMEL_SERVICE (object));
-	use_ssl = camel_url_get_param (url, "use_ssl");
-
-	if (g_strcmp0 (use_ssl, "never") == 0)
-		camel_network_service_set_security_method (
-			CAMEL_NETWORK_SERVICE (object),
-			CAMEL_NETWORK_SECURITY_METHOD_NONE);
-	else if (g_strcmp0 (use_ssl, "always") == 0)
-		camel_network_service_set_security_method (
-			CAMEL_NETWORK_SERVICE (object),
-			CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT);
-	else if (g_strcmp0 (use_ssl, "when-possible") == 0)
-		camel_network_service_set_security_method (
-			CAMEL_NETWORK_SERVICE (object),
-			CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT);
-}
-
 static gboolean
 nntp_can_work_offline (CamelDiscoStore *store)
 {
@@ -797,14 +712,23 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store,
                                        GCancellable *cancellable,
                                        GError **error)
 {
-	gint i;
+	CamelService *service;
+	CamelSettings *settings;
 	CamelStoreInfo *si;
 	CamelFolderInfo *first = NULL, *last = NULL, *fi = NULL;
+	gboolean short_folder_names;
+	gint i;
 
 	/* since we do not do a tree, any request that is not for root is sure to give no results */
 	if (top != NULL && top[0] != 0)
 		return NULL;
 
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	short_folder_names = camel_nntp_settings_get_short_folder_names (
+		CAMEL_NNTP_SETTINGS (settings));
+
 	for (i=0;(si = camel_store_summary_index ((CamelStoreSummary *) store->summary, i));i++) {
 		if (si == NULL)
 			continue;
@@ -837,7 +761,7 @@ nntp_store_get_subscribed_folder_info (CamelNNTPStore *store,
 					g_object_unref (folder);
 				}
 			}
-			fi = nntp_folder_info_from_store_info (store, store->do_short_folder_notation, si);
+			fi = nntp_folder_info_from_store_info (store, short_folder_names, si);
 			fi->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_NOCHILDREN | CAMEL_FOLDER_SYSTEM;
 			if (last)
 				last->next = fi;
@@ -935,6 +859,8 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store,
                                    guint flags,
                                    GError **error)
 {
+	CamelService *service;
+	CamelSettings *settings;
 	gint i;
 	gint subscribed_or_flag = (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED) ? 0 : 1,
 	    root_or_flag = (orig_top == NULL || orig_top[0] == '\0') ? 1 : 0,
@@ -943,10 +869,18 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store,
 	CamelStoreInfo *si;
 	CamelFolderInfo *first = NULL, *last = NULL, *fi = NULL;
 	GHashTable *known; /* folder name to folder info */
+	gboolean folder_hierarchy_relative;
 	gchar *tmpname;
 	gchar *top = g_strconcat(orig_top?orig_top:"", ".", NULL);
 	gint toplen = strlen (top);
 
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	folder_hierarchy_relative =
+		camel_nntp_settings_get_folder_hierarchy_relative (
+		CAMEL_NNTP_SETTINGS (settings));
+
 	known = g_hash_table_new (g_str_hash, g_str_equal);
 
 	for (i = 0; (si = camel_store_summary_index ((CamelStoreSummary *) store->summary, i)); i++) {
@@ -957,7 +891,7 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store,
 				fi = nntp_folder_info_from_store_info (store, FALSE, si);
 				if (!fi)
 					continue;
-				if (store->folder_hierarchy_relative) {
+				if (folder_hierarchy_relative) {
 					g_free (fi->display_name);
 					fi->display_name = g_strdup (si->path + ((toplen == 1) ? 0 : toplen));
 				}
@@ -975,7 +909,7 @@ nntp_store_get_cached_folder_info (CamelNNTPStore *store,
 						continue;
 
 					fi->flags |= CAMEL_FOLDER_NOSELECT;
-					if (store->folder_hierarchy_relative) {
+					if (folder_hierarchy_relative) {
 						g_free (fi->display_name);
 						fi->display_name = g_strdup (tmpname + ((toplen==1) ? 0 : toplen));
 					}
@@ -1197,103 +1131,6 @@ nntp_get_folder_info_offline (CamelStore *store,
 		store, top, flags, FALSE, cancellable, error);
 }
 
-static gboolean
-nntp_store_folder_is_subscribed (CamelStore *store, const gchar *folder_name)
-{
-	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (store);
-	CamelStoreInfo *si;
-	gint truth = FALSE;
-
-	si = camel_store_summary_path ((CamelStoreSummary *) nntp_store->summary, folder_name);
-	if (si) {
-		truth = (si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) != 0;
-		camel_store_summary_info_free ((CamelStoreSummary *) nntp_store->summary, si);
-	}
-
-	return truth;
-}
-
-static gboolean
-nntp_store_subscribe_folder_sync (CamelStore *store,
-                                  const gchar *folder_name,
-                                  GCancellable *cancellable,
-                                  GError **error)
-{
-	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (store);
-	CamelStoreInfo *si;
-	CamelFolderInfo *fi;
-	gboolean success = TRUE;
-
-	camel_service_lock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-
-	si = camel_store_summary_path (CAMEL_STORE_SUMMARY (nntp_store->summary), folder_name);
-	if (!si) {
-		g_set_error (
-			error, CAMEL_FOLDER_ERROR,
-			CAMEL_FOLDER_ERROR_INVALID,
-			_("You cannot subscribe to this newsgroup:\n\n"
-			  "No such newsgroup. The selected item is a "
-			  "probably a parent folder."));
-		success = FALSE;
-	} else {
-		if (!(si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED)) {
-			si->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
-			fi = nntp_folder_info_from_store_info (nntp_store, nntp_store->do_short_folder_notation, si);
-			fi->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_NOCHILDREN;
-			camel_store_summary_touch ((CamelStoreSummary *) nntp_store->summary);
-			camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
-			camel_service_unlock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-			camel_store_folder_subscribed (CAMEL_STORE (nntp_store), fi);
-			camel_folder_info_free (fi);
-			return TRUE;
-		}
-	}
-
-	camel_service_unlock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-
-	return success;
-}
-
-static gboolean
-nntp_store_unsubscribe_folder_sync (CamelStore *store,
-                                    const gchar *folder_name,
-                                    GCancellable *cancellable,
-                                    GError **error)
-{
-	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (store);
-	CamelFolderInfo *fi;
-	CamelStoreInfo *fitem;
-	gboolean success = TRUE;
-
-	camel_service_lock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-
-	fitem = camel_store_summary_path (CAMEL_STORE_SUMMARY (nntp_store->summary), folder_name);
-
-	if (!fitem) {
-		g_set_error (
-			error, CAMEL_FOLDER_ERROR,
-			CAMEL_FOLDER_ERROR_INVALID,
-			_("You cannot unsubscribe to this newsgroup:\n\n"
-			  "newsgroup does not exist!"));
-		success = FALSE;
-	} else {
-		if (fitem->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) {
-			fitem->flags &= ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
-			fi = nntp_folder_info_from_store_info (nntp_store, nntp_store->do_short_folder_notation, fitem);
-			camel_store_summary_touch ((CamelStoreSummary *) nntp_store->summary);
-			camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
-			camel_service_unlock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-			camel_store_folder_unsubscribed (CAMEL_STORE (nntp_store), fi);
-			camel_folder_info_free (fi);
-			return TRUE;
-		}
-	}
-
-	camel_service_unlock (CAMEL_SERVICE (nntp_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-
-	return success;
-}
-
 /* stubs for various folder operations we're not implementing */
 
 static CamelFolderInfo *
@@ -1333,8 +1170,14 @@ nntp_store_delete_folder_sync (CamelStore *store,
                                GCancellable *cancellable,
                                GError **error)
 {
-	nntp_store_unsubscribe_folder_sync (
-		store, folder_name, cancellable, NULL);
+	CamelSubscribable *subscribable;
+	CamelSubscribableInterface *interface;
+
+	subscribable = CAMEL_SUBSCRIBABLE (store);
+	interface = CAMEL_SUBSCRIBABLE_GET_INTERFACE (subscribable);
+
+	interface->unsubscribe_folder_sync (
+		subscribable, folder_name, cancellable, NULL);
 
 	g_set_error (
 		error, CAMEL_FOLDER_ERROR,
@@ -1389,16 +1232,6 @@ nntp_store_initable_init (GInitable *initable,
 	camel_url_free (summary_url);
 	camel_store_summary_load ((CamelStoreSummary *) nntp_store->summary);
 
-	/* get options */
-	if (camel_url_get_param (url, "show_short_notation"))
-		nntp_store->do_short_folder_notation = TRUE;
-	else
-		nntp_store->do_short_folder_notation = FALSE;
-	if (camel_url_get_param (url, "folder_hierarchy_relative"))
-		nntp_store->folder_hierarchy_relative = TRUE;
-	else
-		nntp_store->folder_hierarchy_relative = FALSE;
-
 	/* setup store-wide cache */
 	nntp_store->cache = camel_data_cache_new (user_data_dir, error);
 	if (nntp_store->cache == NULL)
@@ -1412,13 +1245,11 @@ nntp_store_initable_init (GInitable *initable,
 }
 
 static const gchar *
-nntp_store_get_service_name (CamelNetworkService *service)
+nntp_store_get_service_name (CamelNetworkService *service,
+                             CamelNetworkSecurityMethod method)
 {
-	CamelNetworkSecurityMethod method;
 	const gchar *service_name;
 
-	method = camel_network_service_get_security_method (service);
-
 	switch (method) {
 		case CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT:
 			service_name = "nntps";
@@ -1433,13 +1264,11 @@ nntp_store_get_service_name (CamelNetworkService *service)
 }
 
 static guint16
-nntp_store_get_default_port (CamelNetworkService *service)
+nntp_store_get_default_port (CamelNetworkService *service,
+                             CamelNetworkSecurityMethod method)
 {
-	CamelNetworkSecurityMethod method;
 	guint16 default_port;
 
-	method = camel_network_service_get_security_method (service);
-
 	switch (method) {
 		case CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT:
 			default_port = NNTPS_PORT;
@@ -1453,6 +1282,122 @@ nntp_store_get_default_port (CamelNetworkService *service)
 	return default_port;
 }
 
+static gboolean
+nntp_store_folder_is_subscribed (CamelSubscribable *subscribable,
+                                 const gchar *folder_name)
+{
+	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (subscribable);
+	CamelStoreInfo *si;
+	gint truth = FALSE;
+
+	si = camel_store_summary_path ((CamelStoreSummary *) nntp_store->summary, folder_name);
+	if (si) {
+		truth = (si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) != 0;
+		camel_store_summary_info_free ((CamelStoreSummary *) nntp_store->summary, si);
+	}
+
+	return truth;
+}
+
+static gboolean
+nntp_store_subscribe_folder_sync (CamelSubscribable *subscribable,
+                                  const gchar *folder_name,
+                                  GCancellable *cancellable,
+                                  GError **error)
+{
+	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (subscribable);
+	CamelService *service;
+	CamelSettings *settings;
+	CamelStoreInfo *si;
+	CamelFolderInfo *fi;
+	gboolean short_folder_names;
+	gboolean success = TRUE;
+
+	service = CAMEL_SERVICE (subscribable);
+	settings = camel_service_get_settings (service);
+
+	short_folder_names = camel_nntp_settings_get_short_folder_names (
+		CAMEL_NNTP_SETTINGS (settings));
+
+	camel_service_lock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+
+	si = camel_store_summary_path (CAMEL_STORE_SUMMARY (nntp_store->summary), folder_name);
+	if (!si) {
+		g_set_error (
+			error, CAMEL_FOLDER_ERROR,
+			CAMEL_FOLDER_ERROR_INVALID,
+			_("You cannot subscribe to this newsgroup:\n\n"
+			  "No such newsgroup. The selected item is a "
+			  "probably a parent folder."));
+		success = FALSE;
+	} else {
+		if (!(si->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED)) {
+			si->flags |= CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
+			fi = nntp_folder_info_from_store_info (nntp_store, short_folder_names, si);
+			fi->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_NOCHILDREN;
+			camel_store_summary_touch ((CamelStoreSummary *) nntp_store->summary);
+			camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
+			camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+			camel_subscribable_folder_subscribed (subscribable, fi);
+			camel_folder_info_free (fi);
+			return TRUE;
+		}
+	}
+
+	camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+
+	return success;
+}
+
+static gboolean
+nntp_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
+                                    const gchar *folder_name,
+                                    GCancellable *cancellable,
+                                    GError **error)
+{
+	CamelNNTPStore *nntp_store = CAMEL_NNTP_STORE (subscribable);
+	CamelService *service;
+	CamelSettings *settings;
+	CamelFolderInfo *fi;
+	CamelStoreInfo *fitem;
+	gboolean short_folder_names;
+	gboolean success = TRUE;
+
+	service = CAMEL_SERVICE (subscribable);
+	settings = camel_service_get_settings (service);
+
+	short_folder_names = camel_nntp_settings_get_short_folder_names (
+		CAMEL_NNTP_SETTINGS (settings));
+
+	camel_service_lock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+
+	fitem = camel_store_summary_path (CAMEL_STORE_SUMMARY (nntp_store->summary), folder_name);
+
+	if (!fitem) {
+		g_set_error (
+			error, CAMEL_FOLDER_ERROR,
+			CAMEL_FOLDER_ERROR_INVALID,
+			_("You cannot unsubscribe to this newsgroup:\n\n"
+			  "newsgroup does not exist!"));
+		success = FALSE;
+	} else {
+		if (fitem->flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) {
+			fitem->flags &= ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED;
+			fi = nntp_folder_info_from_store_info (nntp_store, short_folder_names, fitem);
+			camel_store_summary_touch ((CamelStoreSummary *) nntp_store->summary);
+			camel_store_summary_save ((CamelStoreSummary *) nntp_store->summary);
+			camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+			camel_subscribable_folder_unsubscribed (subscribable, fi);
+			camel_folder_info_free (fi);
+			return TRUE;
+		}
+	}
+
+	camel_service_unlock (service, CAMEL_SERVICE_REC_CONNECT_LOCK);
+
+	return success;
+}
+
 static void
 camel_nntp_store_class_init (CamelNNTPStoreClass *class)
 {
@@ -1461,28 +1406,21 @@ camel_nntp_store_class_init (CamelNNTPStoreClass *class)
 	CamelStoreClass *store_class;
 	CamelDiscoStoreClass *disco_store_class;
 
-	g_type_class_add_private (class, sizeof (CamelNNTPStorePrivate));
-
 	object_class = G_OBJECT_CLASS (class);
-	object_class->set_property = nntp_store_set_property;
-	object_class->get_property = nntp_store_get_property;
 	object_class->dispose = nntp_store_dispose;
 	object_class->finalize = nntp_store_finalize;
-	object_class->constructed = nntp_store_constructed;
 
 	service_class = CAMEL_SERVICE_CLASS (class);
+	service_class->settings_type = CAMEL_TYPE_NNTP_SETTINGS;
 	service_class->get_name = nntp_store_get_name;
 	service_class->query_auth_types_sync = nntp_store_query_auth_types_sync;
 
 	store_class = CAMEL_STORE_CLASS (class);
 	store_class->can_refresh_folder = nntp_can_refresh_folder;
 	store_class->free_folder_info = camel_store_free_folder_info_full;
-	store_class->folder_is_subscribed = nntp_store_folder_is_subscribed;
 	store_class->create_folder_sync = nntp_store_create_folder_sync;
 	store_class->delete_folder_sync = nntp_store_delete_folder_sync;
 	store_class->rename_folder_sync = nntp_store_rename_folder_sync;
-	store_class->subscribe_folder_sync = nntp_store_subscribe_folder_sync;
-	store_class->unsubscribe_folder_sync = nntp_store_unsubscribe_folder_sync;
 
 	disco_store_class = CAMEL_DISCO_STORE_CLASS (class);
 	disco_store_class->can_work_offline = nntp_can_work_offline;
@@ -1496,24 +1434,6 @@ camel_nntp_store_class_init (CamelNNTPStoreClass *class)
 	disco_store_class->get_folder_info_online = nntp_get_folder_info_online;
 	disco_store_class->get_folder_info_resyncing = nntp_get_folder_info_online;
 	disco_store_class->get_folder_info_offline = nntp_get_folder_info_offline;
-
-	/* Inherited from CamelNetworkService. */
-	g_object_class_override_property (
-		object_class,
-		PROP_DEFAULT_PORT,
-		"default-port");
-
-	/* Inherited from CamelNetworkService. */
-	g_object_class_override_property (
-		object_class,
-		PROP_SECURITY_METHOD,
-		"security-method");
-
-	/* Inherited from CamelNetworkService. */
-	g_object_class_override_property (
-		object_class,
-		PROP_SERVICE_NAME,
-		"service-name");
 }
 
 static void
@@ -1531,16 +1451,22 @@ camel_network_service_init (CamelNetworkServiceInterface *interface)
 	interface->get_default_port = nntp_store_get_default_port;
 }
 
+static void
+camel_subscribable_init (CamelSubscribableInterface *interface)
+{
+	interface->folder_is_subscribed = nntp_store_folder_is_subscribed;
+	interface->subscribe_folder_sync = nntp_store_subscribe_folder_sync;
+	interface->unsubscribe_folder_sync = nntp_store_unsubscribe_folder_sync;
+}
+
 static void
 camel_nntp_store_init (CamelNNTPStore *nntp_store)
 {
-	CamelStore *store = CAMEL_STORE (nntp_store);
-
-	nntp_store->priv = CAMEL_NNTP_STORE_GET_PRIVATE (nntp_store);
-
-	store->flags = CAMEL_STORE_SUBSCRIPTIONS;
-
 	nntp_store->mem = (CamelStreamMem *) camel_stream_mem_new ();
+
+	/* Clear the default flags.  We don't want a virtual Junk or Trash
+	 * folder and the user can't create/delete/rename newsgroup folders. */
+	CAMEL_STORE (nntp_store)->flags = 0;
 }
 
 /* Enter owning lock */
