@@ -104,7 +104,8 @@ gint main (gint argc, gchar **argv)
 		message = camel_mime_message_new ();
 		camel_data_wrapper_construct_from_stream_sync (
 			CAMEL_DATA_WRAPPER (message), stream, NULL, NULL);
-		camel_stream_reset (stream, NULL);
+		g_seekable_seek (
+			G_SEEKABLE (stream), 0, G_SEEK_SET, NULL, NULL);
 
 		/*dump_mime_struct ((CamelMimePart *) message, 0);*/
 		test_message_compare (message);
