@@ -68,8 +68,15 @@ gchar *		e_util_replace_prefix		(const gchar *configure_time_prefix,
 						 const gchar *configure_time_path);
 #endif
 
-void		e_data_server_util_set_dbus_call_timeout (gint timeout_msec);
-gint		e_data_server_util_get_dbus_call_timeout (void);
+gint		e_data_server_util_get_dbus_call_timeout
+						(void);
+void		e_data_server_util_set_dbus_call_timeout
+						(gint timeout_msec);
+
+#define		e_pointer_tracker_track(ptr) e_pointer_tracker_track_with_info (ptr, G_STRFUNC)
+void		e_pointer_tracker_track_with_info (gpointer ptr, const gchar *info);
+void		e_pointer_tracker_untrack (gpointer ptr);
+void		e_pointer_tracker_dump (void);
 
 G_END_DECLS
 
