@@ -25,19 +25,15 @@
 #endif
 
 #include <string.h>
-#include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
-#include <libebook/e-book.h>
+#include <libebook/e-book-client.h>
 #include <libebook/e-contact.h>
-#include <libedataserverui/e-contact-store.h>
-#include <libedataserverui/e-destination-store.h>
-#include <libedataserverui/e-book-auth-util.h>
-#include "e-name-selector.h"
 
-#define E_NAME_SELECTOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_NAME_SELECTOR, ENameSelectorPrivate))
+#include "e-contact-store.h"
+#include "e-destination-store.h"
+#include "e-client-utils.h"
+#include "e-name-selector.h"
 
 typedef struct {
 	gchar *name;
@@ -45,7 +41,7 @@ typedef struct {
 } Section;
 
 typedef struct {
-	EBook *book;
+	EBookClient *client;
 	guint is_completion_book : 1;
 } SourceBook;
 
@@ -56,36 +52,65 @@ struct _ENameSelectorPrivate {
 	GArray *sections;
 	ESourceList *source_list;
 
-	gboolean load_cancelled;
+	gboolean books_loaded;
+	GCancellable *cancellable;
 	GArray *source_books;
 };
 
 G_DEFINE_TYPE (ENameSelector, e_name_selector, G_TYPE_OBJECT)
 
 static void
-name_selector_book_loaded_cb (ESource *source,
-                              GAsyncResult *result,
-                              ENameSelector *name_selector)
+reset_pointer_cb (gpointer data, GObject *where_was)
 {
-	EBook *book;
+	ENameSelector *name_selector = data;
+	ENameSelectorPrivate *priv;
+	guint ii;
+
+	g_return_if_fail (E_IS_NAME_SELECTOR (name_selector));
+
+	priv = name_selector->priv;
+
+	for (ii = 0; ii < priv->sections->len; ii++) {
+		Section *section;
+
+		section = &g_array_index (priv->sections, Section, ii);
+		if (section->entry == (ENameSelectorEntry *) where_was)
+			section->entry = NULL;
+	}
+}
+
+static void
+name_selector_book_loaded_cb (GObject *source_object,
+                              GAsyncResult *result,
+                              gpointer user_data)
+{
+	ENameSelector *name_selector = user_data;
+	ESource *source = E_SOURCE (source_object);
+	EBookClient *book_client;
+	EClient *client = NULL;
 	GArray *sections;
 	SourceBook source_book;
 	guint ii;
 	GError *error = NULL;
 
-	book = e_load_book_source_finish (source, result, &error);
+	e_client_utils_open_new_finish (source, result, &client, &error);
 
 	if (error != NULL) {
-		g_warning (
-			"ENameSelector: Could not load \"%s\": %s",
-			e_source_peek_name (source), error->message);
+		if (!g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_REPOSITORY_OFFLINE)
+		    && !g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_OFFLINE_UNAVAILABLE)
+		    && !g_error_matches (error, E_CLIENT_ERROR, E_CLIENT_ERROR_CANCELLED)
+		    && !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+			g_warning (
+				"ENameSelector: Could not load \"%s\": %s",
+				e_source_peek_name (source), error->message);
 		g_error_free (error);
 		goto exit;
 	}
 
-	g_return_if_fail (E_IS_BOOK (book));
+	book_client = E_BOOK_CLIENT (client);
+	g_return_if_fail (E_IS_BOOK_CLIENT (book_client));
 
-	source_book.book = book;
+	source_book.client = book_client;
 	source_book.is_completion_book = TRUE;
 
 	g_array_append_val (name_selector->priv->source_books, source_book);
@@ -103,21 +128,38 @@ name_selector_book_loaded_cb (ESource *source,
 		store = e_name_selector_entry_peek_contact_store (
 			section->entry);
 		if (store != NULL)
-			e_contact_store_add_book (store, book);
+			e_contact_store_add_client (store, book_client);
 	}
 
-exit:
+ exit:
 	g_object_unref (name_selector);
 }
 
-static void
-name_selector_load_books (ENameSelector *name_selector)
+/**
+ * e_name_selector_load_books:
+ * @name_selector: an #ENameSelector
+ *
+ * Loads address books available for the @name_selector.
+ * This can be called only once and it can be cancelled
+ * by e_name_selector_cancel_loading().
+ *
+ * Since: 3.2
+ **/
+void
+e_name_selector_load_books (ENameSelector *name_selector)
 {
 	ESourceList *source_list;
 	GSList *groups;
 	GSList *iter1;
 
-	if (!e_book_get_addressbooks (&source_list, NULL)) {
+	g_return_if_fail (name_selector != NULL);
+	g_return_if_fail (E_IS_NAME_SELECTOR (name_selector));
+	g_return_if_fail (name_selector->priv != NULL);
+	g_return_if_fail (!name_selector->priv->books_loaded);
+
+	name_selector->priv->books_loaded = TRUE;
+
+	if (!e_book_client_get_sources (&source_list, NULL)) {
 		g_warning ("ENameSelector can't find any addressbooks!");
 		return;
 	}
@@ -154,23 +196,47 @@ name_selector_load_books (ENameSelector *name_selector)
 			if (g_ascii_strcasecmp (property, "true") != 0)
 				continue;
 
-			/* XXX Should we allow for cancellation? */
-			e_load_book_source_async (
-				source, NULL, NULL,
-				(GAsyncReadyCallback)
-				name_selector_book_loaded_cb,
-				g_object_ref (name_selector));
+			e_client_utils_open_new (
+				source, E_CLIENT_SOURCE_TYPE_CONTACTS, TRUE, name_selector->priv->cancellable,
+				e_client_utils_authenticate_handler, NULL,
+				name_selector_book_loaded_cb, g_object_ref (name_selector));
 		}
 	}
 }
 
+/**
+ * e_name_selector_cancel_loading:
+ * @name_selector: an #ENameSelector
+ *
+ * Cancels any pending address book load operations. This might be called
+ * before an owner unrefs this @name_selector.
+ *
+ * Since: 3.2
+ **/
+void
+e_name_selector_cancel_loading (ENameSelector *name_selector)
+{
+	g_return_if_fail (name_selector != NULL);
+	g_return_if_fail (E_IS_NAME_SELECTOR (name_selector));
+	g_return_if_fail (name_selector->priv != NULL);
+	g_return_if_fail (name_selector->priv->cancellable != NULL);
+
+	g_cancellable_cancel (name_selector->priv->cancellable);
+}
+
 static void
 name_selector_dispose (GObject *object)
 {
 	ENameSelectorPrivate *priv;
 	guint ii;
 
-	priv = E_NAME_SELECTOR_GET_PRIVATE (object);
+	priv = E_NAME_SELECTOR (object)->priv;
+
+	if (priv->cancellable) {
+		g_cancellable_cancel (priv->cancellable);
+		g_object_unref (priv->cancellable);
+		priv->cancellable = NULL;
+	}
 
 	if (priv->source_list != NULL) {
 		g_object_unref (priv->source_list);
@@ -182,11 +248,21 @@ name_selector_dispose (GObject *object)
 
 		source_book = &g_array_index (
 			priv->source_books, SourceBook, ii);
-		if (source_book->book != NULL)
-			g_object_unref (source_book->book);
+		if (source_book->client != NULL)
+			g_object_unref (source_book->client);
+	}
+
+	for (ii = 0; ii < priv->sections->len; ii++) {
+		Section *section;
+
+		section = &g_array_index (priv->sections, Section, ii);
+		if (section->entry)
+			g_object_weak_unref (G_OBJECT (section->entry), reset_pointer_cb, object);
+		g_free (section->name);
 	}
 
 	g_array_set_size (priv->source_books, 0);
+	g_array_set_size (priv->sections, 0);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_name_selector_parent_class)->dispose (object);
@@ -197,9 +273,10 @@ name_selector_finalize (GObject *object)
 {
 	ENameSelectorPrivate *priv;
 
-	priv = E_NAME_SELECTOR_GET_PRIVATE (object);
+	priv = E_NAME_SELECTOR (object)->priv;
 
 	g_array_free (priv->source_books, TRUE);
+	g_array_free (priv->sections, TRUE);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (e_name_selector_parent_class)->finalize (object);
@@ -226,12 +303,13 @@ e_name_selector_init (ENameSelector *name_selector)
 	sections = g_array_new (FALSE, FALSE, sizeof (Section));
 	source_books = g_array_new (FALSE, FALSE, sizeof (SourceBook));
 
-	name_selector->priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
+	name_selector->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		name_selector, E_TYPE_NAME_SELECTOR, ENameSelectorPrivate);
 	name_selector->priv->sections = sections;
 	name_selector->priv->model = e_name_selector_model_new ();
 	name_selector->priv->source_books = source_books;
-
-	name_selector_load_books (name_selector);
+	name_selector->priv->cancellable = g_cancellable_new ();
+	name_selector->priv->books_loaded = FALSE;
 }
 
 /**
@@ -388,7 +466,7 @@ e_name_selector_peek_section_entry (ENameSelector *name_selector, const gchar *n
 	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 
-	priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
+	priv = name_selector->priv;
 	model = e_name_selector_peek_model (name_selector);
 
 	if (!e_name_selector_model_peek_section (
@@ -407,6 +485,7 @@ e_name_selector_peek_section_entry (ENameSelector *name_selector, const gchar *n
 		gint           i;
 
 		section->entry = e_name_selector_entry_new ();
+		g_object_weak_ref (G_OBJECT (section->entry), reset_pointer_cb, name_selector);
 		if (pango_parse_markup (name, -1, '_', NULL,
 					&text, NULL, NULL))  {
 			atk_object_set_name (gtk_widget_get_accessible (GTK_WIDGET (section->entry)), text);
@@ -421,8 +500,8 @@ e_name_selector_peek_section_entry (ENameSelector *name_selector, const gchar *n
 		for (i = 0; i < priv->source_books->len; i++) {
 			SourceBook *source_book = &g_array_index (priv->source_books, SourceBook, i);
 
-			if (source_book->is_completion_book && source_book->book)
-				e_contact_store_add_book (contact_store, source_book->book);
+			if (source_book->is_completion_book && source_book->client)
+				e_contact_store_add_client (contact_store, source_book->client);
 		}
 
 		e_name_selector_entry_set_contact_store (section->entry, contact_store);
@@ -455,7 +534,7 @@ e_name_selector_peek_section_list (ENameSelector *name_selector, const gchar *na
 	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 
-	priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
+	priv = name_selector->priv;
 	model = e_name_selector_peek_model (name_selector);
 
 	if (!e_name_selector_model_peek_section (
@@ -474,6 +553,7 @@ e_name_selector_peek_section_list (ENameSelector *name_selector, const gchar *na
 		gint           i;
 
 		section->entry = (ENameSelectorEntry *) e_name_selector_list_new ();
+		g_object_weak_ref (G_OBJECT (section->entry), reset_pointer_cb, name_selector);
 		if (pango_parse_markup (name, -1, '_', NULL,
 					&text, NULL, NULL))  {
 			atk_object_set_name (gtk_widget_get_accessible (GTK_WIDGET (section->entry)), text);
@@ -487,14 +567,13 @@ e_name_selector_peek_section_list (ENameSelector *name_selector, const gchar *na
 		for (i = 0; i < priv->source_books->len; i++) {
 			SourceBook *source_book = &g_array_index (priv->source_books, SourceBook, i);
 
-			if (source_book->is_completion_book && source_book->book)
-				e_contact_store_add_book (contact_store, source_book->book);
+			if (source_book->is_completion_book && source_book->client)
+				e_contact_store_add_client (contact_store, source_book->client);
 		}
 
 		e_name_selector_entry_set_contact_store (section->entry, contact_store);
 		g_object_unref (contact_store);
 	}
 
-	return (ENameSelectorList *)section->entry;
+	return (ENameSelectorList *) section->entry;
 }
-
