@@ -39,12 +39,12 @@ void e_passwords_init (void);
 void        e_passwords_shutdown          (void);
 void	    e_passwords_cancel (void);
 void        e_passwords_set_online (gint state);
-void        e_passwords_remember_password (const gchar *component, const gchar *key);
+void        e_passwords_remember_password (const gchar *unused, const gchar *key);
 void        e_passwords_add_password      (const gchar *key, const gchar *passwd);
-gchar       *e_passwords_get_password      (const gchar *component, const gchar *key);
-void        e_passwords_forget_password   (const gchar *component, const gchar *key);
+gchar       *e_passwords_get_password      (const gchar *unused, const gchar *key);
+void        e_passwords_forget_password   (const gchar *unused, const gchar *key);
 void        e_passwords_forget_passwords  (void);
-void        e_passwords_clear_passwords (const gchar *component);
+void        e_passwords_clear_passwords (const gchar *unused);
 
 typedef enum {
 	E_PASSWORDS_REMEMBER_NEVER,
@@ -61,7 +61,7 @@ typedef enum {
 } EPasswordsRememberType;
 
 gchar *      e_passwords_ask_password      (const gchar *title,
-					   const gchar *component_name, const gchar *key,
+					   const gchar *unused, const gchar *key,
 					   const gchar *prompt,
 					   EPasswordsRememberType remember_type,
 					   gboolean *remember,
